@@ -583,7 +583,7 @@ class NcmClient:
             '{0}/configuration_managers/{1}/?fields=configuration'.format(
                 self.base_url, str(configman_id)),
             json=payload)  # Patch indie config with new values
-        result = self.__returnhandler(ncm.status_code, ncm.text, call_type)
+        result = self.__return_handler(ncm.status_code, ncm.text, call_type)
         return result
 
     def patch_group_configuration(self, group_id, config_json):
@@ -651,7 +651,7 @@ class NcmClient:
             '{0}/configuration_managers/{1}/'.format(self.base_url,
                                                      str(configman_id)),
             json=payload)
-        result = self.__returnhandler(ncm.status_code, ncm.text, call_type)
+        result = self.__return_handler(ncm.status_code, ncm.text, call_type)
         return result
 
     def get_device_app_bindings(self, **kwargs):
@@ -1167,7 +1167,7 @@ class NcmClient:
         get_url = '{0}/net_devices/'.format(self.base_url)
 
         allowed_params = ['account', 'account__in', 'connection_state',
-                          'connection_state__in', 'id', 'id__in',
+                          'connection_state__in', 'fields', 'id', 'id__in',
                           'is_asset', 'ipv4_address', 'ipv4_address__in',
                           'mode', 'mode__in', 'router', 'router__in',
                           'expand', 'limit', 'offset']
@@ -1630,6 +1630,70 @@ class NcmClient:
         return self.delete_router_by_id(
             self.get_router_by_name(router_name)['id'])
 
+    def create_speed_test(self, net_device_ids: list, account_id=None,
+                          host="netperf-west.bufferbloat.net",
+                          max_test_concurrency=5, port=12865, size=None,
+                          test_timeout=10, test_type="TCP Download", time=10):
+        """
+        This operation creates a speed test using Netperf.
+
+        Usage Example:
+        n.create_speed_test([12345])
+
+        :param account_id: Account in which to create the speed_test record.
+        :param host: URL of Speedtest Server.
+        :param max_test_concurrency: Number of maximum simultaneous tests to server (1-50).
+        :param net_device_ids: List of net_device IDs (up to 10,000 net_device IDs per request).
+        :param port: TCP port for test.
+        :param size: Number of bytes to transfer.
+        :param test_timeout: Test timeout in seconds.
+        :param test_type: TCP Download, TCP Upload, TCP Latency
+        :param time: Test time
+        :return:
+        """
+        call_type = 'Speed Test'
+        post_url = '{0}/speed_test/'.format(self.base_url)
+
+        if account_id is None:
+            account_id = self.get_accounts()[0]['id']
+
+        post_data = {
+            "account": f"https://www.cradlepointecm.com/api/v2/accounts/{account_id}/",
+            "config": {
+                "host": host,
+                "max_test_concurrency": max_test_concurrency,
+                "net_device_ids": net_device_ids,
+                "port": port,
+                "size": size,
+                "test_timeout": test_timeout,
+                "test_type": test_type,
+                "time": time
+            }
+        }
+
+        ncm = self.session.post(post_url, data=json.dumps(post_data))
+        if ncm.status_code == 201:
+            return ncm.json()
+        else:
+            return ncm.text
+
+    def get_speed_test(self, speed_test_id, **kwargs):
+        """
+        This method gets the status/results of a created speed test.
+
+        Usage Example:
+        speed_test = n.create_speed_test([123456])
+        n.get_speed_test(speed_test['id'])
+
+        :param speed_test_id: ID of a speed_test record
+        :return:
+        """
+        call_type = 'Speed Test'
+        get_url = '{0}/speed_test/{1}/'.format(self.base_url, speed_test_id)
+
+        return self.session.get(get_url).json()
+
+
     def set_lan_ip_address(self, router_id, lan_ip, netmask=None,
                            network_id=0):
         """
